@@ -1,23 +1,28 @@
-use super::SYSTEM;
+use super::MyView;
 use crate::{
-    styles::colors::*,
-    widgets::{Card, Dial},
+    gui::styles::colors::*,
+    gui::widgets::{Card, Dial},
 };
 use fltk::{prelude::*, *};
 use sysinfo::DiskExt;
 use sysinfo::SystemExt;
 
-pub fn disks() -> group::Pack {
-    let mut sys = SYSTEM.lock();
-    sys.refresh_all();
+pub fn disks(view: &MyView) -> group::Pack {
+    let mut sys = view.system.lock();
+    sys.refresh_disks();
     frame::Frame::new(60, 60, 0, 0, None);
-    let mut grp = group::Pack::new(60, 60, 600, 400, None).center_of_parent();
+    let mut grp = group::Pack::default()
+        .with_size(600, 400)
+        .center_of_parent();
     grp.set_spacing(40);
     for disk in sys.disks() {
-        let mut hpack =
-            group::Pack::new(0, 0, 600, 130, None).with_type(group::PackType::Horizontal);
+        let mut hpack = group::Pack::default()
+            .with_size(600, 130)
+            .with_type(group::PackType::Horizontal);
         hpack.set_spacing(50);
-        let t = Card::new(0, 0, 300, 130, disk.name().to_str().unwrap());
+        let t = Card::default()
+            .with_size(300, 130)
+            .with_label(disk.name().to_str().unwrap());
         t.begin();
         frame::Frame::default()
             .with_size(80, 60)
@@ -30,7 +35,10 @@ pub fn disks() -> group::Pack {
             .center_of_parent();
         t.end();
         let grp = group::Group::default().with_size(130, 130);
-        let mut dial = Dial::new(0, 0, 100, 100, "Used space %").center_of_parent();
+        let mut dial = Dial::default()
+            .with_size(100, 100)
+            .with_label("Used space %")
+            .center_of_parent();
         dial.modifiable(false);
         dial.set_value(
             ((disk.total_space() - disk.available_space()) as f64 * 100.
@@ -41,5 +49,6 @@ pub fn disks() -> group::Pack {
         hpack.end();
     }
     grp.end();
+    drop(sys);
     grp
 }
